==> FreeBagSlots_v0.07.zip: Interface/AddOns/FreeBagSlots/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_FREEBAGSLOTSHEADER						= "Free Bag Slots";
BINDING_NAME_FREEBAGSLOTS								= "Free Bag Slots Toggle";

FREEBAGSLOTS_CONFIG_HEADER								= "Free Bag Slots";
FREEBAGSLOTS_CONFIG_HEADER_INFO							= "Contains settings for the Free Bag Slots,\nan AddOn which...";

FREEBAGSLOTS_ENABLED									= "Enable Free Bag Slots";
FREEBAGSLOTS_ENABLED_INFO								= "Enables Free Bag Slots, which will allow you to see how many slots you have left in each bag.";

FREEBAGSLOTS_CHAT_ENABLED								= "Free Bag Slots enabled.";
FREEBAGSLOTS_CHAT_DISABLED								= "Free Bag Slots disabled.";

FREEBAGSLOTS_CHAT_COMMAND_ENABLE_INFO					= "Enables/disables Free Bag Slots.";

FREEBAGSLOTS_SHOW_TOTAL_SLOTS							= "Toggle showing of total slots (X/Y)";
FREEBAGSLOTS_SHOW_TOTAL_SLOTS_INFO						= "Will show total number of slots with the free number of slots in the bags";

FREEBAGSLOTS_CHAT_SHOW_TOTAL_SLOTS_ENABLED				= "Free Bag Slots show total number of slots enabled.";
FREEBAGSLOTS_CHAT_SHOW_TOTAL_SLOTS_DISABLED				= "Free Bag Slots show total number of slots disabled.";

FREEBAGSLOTS_SHOW_EMPTY_SLOTS_ON_SHOTBAGS				= "Toggle showing of empty slots on shot bags";
FREEBAGSLOTS_SHOW_EMPTY_SLOTS_ON_SHOTBAGS_INFO			= "Will show number of empty slots on shotbags.";

FREEBAGSLOTS_CHAT_SHOW_EMPTY_SLOTS_ON_SHOTBAGS_ENABLED	= "Free Bag Slots show empty slots on shot bags enabled.";
FREEBAGSLOTS_CHAT_SHOW_EMPTY_SLOTS_ON_SHOTBAGS_DISABLED	= "Free Bag Slots show empty slots on shot bags disabled.";

FREEBAGSLOTS_SHOW_FREE_TOTAL_SLOTS						= "Toggle showing of total free slots";
FREEBAGSLOTS_SHOW_FREE_TOTAL_SLOTS_INFO					= "Will show total number of free slots in the bags";

FREEBAGSLOTS_CHAT_SHOW_TOTAL_FREE_SLOTS_ENABLED			= "Free Bag Slots show total number of free slots enabled.";
FREEBAGSLOTS_CHAT_SHOW_TOTAL_FREE_SLOTS_DISABLED		= "Free Bag Slots show total number of free slots disabled.";

FREEBAGSLOTS_CHAT_COMMAND_INFO							= "Controls the weapon buttons by the command line. Use /freebagslots to get usage help.";

FREEBAGSLOTS_CHAT_COMMAND_USAGE							= "Usage: /freebagslots <show/totalslots/shotbags> [on/off/toggle]\nCommands:\n show - determines whether the FreeBagSlots should be visible\n totalslots - shows the total number of slots of each bag";

==> FreeBagSlots_v0.10.zip: Interface/AddOns/FreeBagSlots/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_FREEBAGSLOTSHEADER						= "Free Bag Slots";
BINDING_NAME_FREEBAGSLOTS								= "Free Bag Slots Toggle";

FREEBAGSLOTS_CONFIG_HEADER								= "Free Bag Slots";
FREEBAGSLOTS_CONFIG_HEADER_INFO							= "Contains settings for the Free Bag Slots,\nan AddOn which...";

FREEBAGSLOTS_ENABLED									= "Enable Free Bag Slots";
FREEBAGSLOTS_ENABLED_INFO								= "Enables Free Bag Slots, which will allow you to see how many slots you have left in each bag.";

FREEBAGSLOTS_CHAT_ENABLED								= "Free Bag Slots enabled.";
FREEBAGSLOTS_CHAT_DISABLED								= "Free Bag Slots disabled.";

FREEBAGSLOTS_CHAT_COMMAND_ENABLE_INFO					= "Enables/disables Free Bag Slots.";

FREEBAGSLOTS_SHOW_TOTAL_SLOTS							= "Toggle showing of total slots (X/Y)";
FREEBAGSLOTS_SHOW_TOTAL_SLOTS_INFO						= "Will show total number of slots with the free number of slots in the bags";

FREEBAGSLOTS_CHAT_SHOW_TOTAL_SLOTS_ENABLED				= "Free Bag Slots show total number of slots enabled.";
FREEBAGSLOTS_CHAT_SHOW_TOTAL_SLOTS_DISABLED				= "Free Bag Slots show total number of slots disabled.";

FREEBAGSLOTS_SHOW_EMPTY_SLOTS_ON_SHOTBAGS				= "Toggle showing of empty slots on shot bags";
FREEBAGSLOTS_SHOW_EMPTY_SLOTS_ON_SHOTBAGS_INFO			= "Will show number of empty slots on shotbags.";

FREEBAGSLOTS_CHAT_SHOW_EMPTY_SLOTS_ON_SHOTBAGS_ENABLED	= "Free Bag Slots show empty slots on shot bags enabled.";
FREEBAGSLOTS_CHAT_SHOW_EMPTY_SLOTS_ON_SHOTBAGS_DISABLED	= "Free Bag Slots show empty slots on shot bags disabled.";

FREEBAGSLOTS_SHOW_TOTAL_FREE_SLOTS						= "Toggle showing of total free slots";
FREEBAGSLOTS_SHOW_TOTAL_FREE_SLOTS_INFO					= "Will show total number of free slots in the bags";

FREEBAGSLOTS_CHAT_SHOW_TOTAL_FREE_SLOTS_ENABLED			= "Free Bag Slots show total number of free slots enabled.";
FREEBAGSLOTS_CHAT_SHOW_TOTAL_FREE_SLOTS_DISABLED		= "Free Bag Slots show total number of free slots disabled.";

FREEBAGSLOTS_SHOW_GLOBAL_SLOTS							= "Toggle showing of global slots";
FREEBAGSLOTS_SHOW_GLOBAL_SLOTS_INFO						= "Will show the global number of slots available (and total if specified) on the backpack.";

FREEBAGSLOTS_CHAT_SHOW_GLOBAL_SLOTS_ENABLED				= "Free Bag Slots show global number of slots enabled.";
FREEBAGSLOTS_CHAT_SHOW_GLOBAL_SLOTS_DISABLED			= "Free Bag Slots show global number of slots disabled.";

FREEBAGSLOTS_CHAT_COMMAND_INFO							= "Controls the weapon buttons by the command line. Use /freebagslots to get usage help.";

FREEBAGSLOTS_CHAT_COMMAND_USAGE							= "Usage: /freebagslots <show/totalslots/shotbags> [on/off/toggle]\nCommands:\n show - determines whether the FreeBagSlots should be visible\n totalslots - shows the total number of slots of each bag";
